@@ -2,7 +2,8 @@
 # -*- coding: utf-8 -*-
 # KEEP THAT! ^^^^^
 
-# This is for the website:
+from blessed import Terminal
+
 class Term:
 	def __getattribute__(self, name):
 		class _r:
@@ -10,4 +11,8 @@ class Term:
 				return ""
 			def __call__(self, i, *args, **kwargs):
 				return i
-		return _r()
\ No newline at end of file
+		return _r()
+
+
+Term = Terminal
+# ^^ Uncomment that for regular ANSI ^^
\ No newline at end of file
